==> pana-0.21.27.tar.gz: test/goldens/end2end/url_launcher-6.1.2.json_report.md <==
## 30/30 Follow Dart file conventions

### [*] 10/10 points: Provide a valid `pubspec.yaml`


### [*] 5/5 points: Provide a valid `README.md`


### [*] 5/5 points: Provide a valid `CHANGELOG.md`


### [*] 10/10 points: Use an OSI-approved license

Detected license: `BSD-3-Clause`.

## 10/10 Provide documentation

### [*] 10/10 points: Package has an example


## 20/20 Platform support

### [*] 20/20 points: Supports 6 of 6 possible platforms (**iOS**, **Android**, **Web**, **Windows**, **MacOS**, **Linux**)

* ✓ Android
* ✓ iOS
* ✓ Windows
* ✓ Linux
* ✓ MacOS
* ✓ Web

## 30/30 Pass static analysis

### [*] 30/30 points: code has no errors, warnings, lints, or formatting issues


## 20/20 Support up-to-date dependencies

### [*] 10/10 points: All of the package dependencies are supported in the latest version

|Package|Constraint|Compatible|Latest|
|:-|:-|:-|:-|
|[`flutter`]|`flutter`|0.0.0|0.0.0|
|[`url_launcher_android`]|`^6.0.13`|6.0.19|6.0.19|
|[`url_launcher_ios`]|`^6.0.13`|6.0.17|6.0.17|
|[`url_launcher_linux`]|`>=2.0.0 <4.0.0`|3.0.1|3.0.1|
|[`url_launcher_macos`]|`>=2.0.0 <4.0.0`|3.0.1|3.0.1|
|[`url_launcher_platform_interface`]|`^2.0.3`|2.1.1|2.1.1|
|[`url_launcher_web`]|`^2.0.0`|2.0.13|2.0.13|
|[`url_launcher_windows`]|`>=2.0.0 <4.0.0`|3.0.1|3.0.1|

<details><summary>Transitive dependencies</summary>

|Package|Constraint|Compatible|Latest|
|:-|:-|:-|:-|
|[`characters`]|-|1.2.1|1.2.1|
|[`collection`]|-|1.17.0|1.17.0|
|[`flutter_web_plugins`]|-|0.0.0|0.0.0|
|[`js`]|-|0.6.5|0.6.5|
|[`material_color_utilities`]|-|0.2.0|0.2.0|
|[`meta`]|-|1.8.0|1.8.0|
|[`plugin_platform_interface`]|-|2.1.3|2.1.3|
|[`sky_engine`]|-|0.0.99|0.0.99|
|[`vector_math`]|-|2.1.4|2.1.4|
</details>

To reproduce run `dart pub outdated --no-dev-dependencies --up-to-date --no-dependency-overrides`.

[`flutter`]: https://pub.dev/packages/flutter
[`url_launcher_android`]: https://pub.dev/packages/url_launcher_android
[`url_launcher_ios`]: https://pub.dev/packages/url_launcher_ios
[`url_launcher_linux`]: https://pub.dev/packages/url_launcher_linux
[`url_launcher_macos`]: https://pub.dev/packages/url_launcher_macos
[`url_launcher_platform_interface`]: https://pub.dev/packages/url_launcher_platform_interface
[`url_launcher_web`]: https://pub.dev/packages/url_launcher_web
[`url_launcher_windows`]: https://pub.dev/packages/url_launcher_windows
[`characters`]: https://pub.dev/packages/characters
[`collection`]: https://pub.dev/packages/collection
[`flutter_web_plugins`]: https://pub.dev/packages/flutter_web_plugins
[`js`]: https://pub.dev/packages/js
[`material_color_utilities`]: https://pub.dev/packages/material_color_utilities
[`meta`]: https://pub.dev/packages/meta
[`plugin_platform_interface`]: https://pub.dev/packages/plugin_platform_interface
[`sky_engine`]: https://pub.dev/packages/sky_engine
[`vector_math`]: https://pub.dev/packages/vector_math


### [*] 10/10 points: Package supports latest stable Dart and Flutter SDKs


## 20/20 Support sound null safety

### [*] 20/20 points: Package and dependencies are fully migrated to null safety!

==> pana-0.21.33.tar.gz: test/goldens/end2end/url_launcher-6.1.2.json_report.md <==
## 30/30 Follow Dart file conventions

### [*] 10/10 points: Provide a valid `pubspec.yaml`


### [*] 5/5 points: Provide a valid `README.md`


### [*] 5/5 points: Provide a valid `CHANGELOG.md`


### [*] 10/10 points: Use an OSI-approved license

Detected license: `BSD-3-Clause`.

## 10/10 Provide documentation

### [*] 10/10 points: Package has an example


## 20/20 Platform support

### [*] 20/20 points: Supports 6 of 6 possible platforms (**iOS**, **Android**, **Web**, **Windows**, **MacOS**, **Linux**)

* ✓ Android
* ✓ iOS
* ✓ Windows
* ✓ Linux
* ✓ MacOS
* ✓ Web

## 20/30 Pass static analysis

### [~] 20/30 points: code has no errors, warnings, lints, or formatting issues

* Running `dartfmt` failed.

## 20/20 Support up-to-date dependencies

### [*] 10/10 points: All of the package dependencies are supported in the latest version

|Package|Constraint|Compatible|Latest|
|:-|:-|:-|:-|
|[`flutter`]|`flutter`|0.0.0|0.0.0|
|[`url_launcher_android`]|`^6.0.13`|6.0.31|6.0.31|
|[`url_launcher_ios`]|`^6.0.13`|6.1.4|6.1.4|
|[`url_launcher_linux`]|`>=2.0.0 <4.0.0`|3.0.5|3.0.5|
|[`url_launcher_macos`]|`>=2.0.0 <4.0.0`|3.0.5|3.0.5|
|[`url_launcher_platform_interface`]|`^2.0.3`|2.1.2|2.1.2|
|[`url_launcher_web`]|`^2.0.0`|2.0.16|2.0.16|
|[`url_launcher_windows`]|`>=2.0.0 <4.0.0`|3.0.6|3.0.6|

<details><summary>Transitive dependencies</summary>

|Package|Constraint|Compatible|Latest|
|:-|:-|:-|:-|
|[`characters`]|-|1.3.0|1.3.0|
|[`collection`]|-|1.17.1|1.17.1|
|[`flutter_web_plugins`]|-|0.0.0|0.0.0|
|[`js`]|-|0.6.7|0.6.7|
|[`material_color_utilities`]|-|0.2.0|0.5.0|
|[`meta`]|-|1.9.1|1.9.1|
|[`plugin_platform_interface`]|-|2.1.4|2.1.4|
|[`sky_engine`]|-|0.0.99|0.0.99|
|[`vector_math`]|-|2.1.4|2.1.4|
</details>

To reproduce run `dart pub outdated --no-dev-dependencies --up-to-date --no-dependency-overrides`.

[`flutter`]: https://pub.dev/packages/flutter
[`url_launcher_android`]: https://pub.dev/packages/url_launcher_android
[`url_launcher_ios`]: https://pub.dev/packages/url_launcher_ios
[`url_launcher_linux`]: https://pub.dev/packages/url_launcher_linux
[`url_launcher_macos`]: https://pub.dev/packages/url_launcher_macos
[`url_launcher_platform_interface`]: https://pub.dev/packages/url_launcher_platform_interface
[`url_launcher_web`]: https://pub.dev/packages/url_launcher_web
[`url_launcher_windows`]: https://pub.dev/packages/url_launcher_windows
[`characters`]: https://pub.dev/packages/characters
[`collection`]: https://pub.dev/packages/collection
[`flutter_web_plugins`]: https://pub.dev/packages/flutter_web_plugins
[`js`]: https://pub.dev/packages/js
[`material_color_utilities`]: https://pub.dev/packages/material_color_utilities
[`meta`]: https://pub.dev/packages/meta
[`plugin_platform_interface`]: https://pub.dev/packages/plugin_platform_interface
[`sky_engine`]: https://pub.dev/packages/sky_engine
[`vector_math`]: https://pub.dev/packages/vector_math


### [*] 10/10 points: Package supports latest stable Dart and Flutter SDKs


## 20/20 Dart 3 & Flutter 3.10 compatibility

### [*] 20/20 points: Package is Dart 3 & Flutter 3.10 compatible!
